@@ -9,6 +9,17 @@ namespace FSpot {
 			LoadItems ();
 		}
 
+		public int Count {
+			get {
+				return items.Length;
+			}
+		}
+
+		public bool Contains (IBrowsableItem item)
+		{
+			return IndexOf (item) >= 0;
+		}
+
 		// IBrowsableCollection
 		public IBrowsableItem [] Items {
 			get {
@@ -16,6 +27,12 @@ namespace FSpot {
 			}
 		}
 
+		public IBrowsableItem this [int index] {
+			get {
+				return items [index];
+			}
+		}
+
 		public event FSpot.IBrowsableCollectionChangedHandler Changed;
 		public event FSpot.IBrowsableCollectionItemChangedHandler ItemChanged;
 
@@ -30,6 +47,17 @@ namespace FSpot {
 			}
 		}
 
+		public int IndexOf (IBrowsableItem item)
+		{
+			return System.Array.IndexOf (items, item);
+		}
+
+		public void MarkChanged (int num)
+		{
+			if (this.ItemChanged != null)
+				this.ItemChanged (this, num);
+		}
+
 		void LoadItems () {
 			// FIXME this should probably actually throw and exception
 			// if the directory doesn't exist.
@@ -39,12 +67,15 @@ namespace FSpot {
 				System.IO.DirectoryInfo info = new System.IO.DirectoryInfo (path);
 				System.IO.FileInfo [] files = info.GetFiles ();
 				foreach (System.IO.FileInfo f in files) {
-					System.Console.WriteLine (f.FullName);
-					
-					images.Add (new FileBrowsableItem (f.FullName));
+					if (FSpot.ImageFile.HasLoader (f.FullName)) {
+						System.Console.WriteLine (f.FullName);
+						images.Add (new FileBrowsableItem (f.FullName));
+					}
 				}
 				
 				items = images.ToArray (typeof (FileBrowsableItem)) as FileBrowsableItem [];
+			} else if (System.IO.File.Exists (path)) {
+				items = new FileBrowsableItem [] { new FileBrowsableItem (path) };
 			} else {
 				items = new FileBrowsableItem [0];
 			}
@@ -54,11 +85,25 @@ namespace FSpot {
 
 	public class FileBrowsableItem : IBrowsableItem {
 		ImageFile img;
+		string path;
+		bool attempted;
+
 		public FileBrowsableItem (string path)
 		{
-			this.img = ImageFile.Create (path);
+			this.path = path;
 		}
 		
+		protected ImageFile Image {
+			get {
+				if (!attempted) {
+					img = ImageFile.Create (path);
+					attempted = true;
+				}
+
+				return img;
+			}
+		}
+
 		public Tag [] Tags {
 			get {
 				return null;
@@ -67,20 +112,20 @@ namespace FSpot {
 
 		public System.DateTime Time {
 			get {
-				return img.Date ();
+				return Image.Date;
 			}
 		}
 		
 		public System.Uri DefaultVersionUri {
 			get {
-				return UriList.PathToFileUri (img.Path);
+				return UriList.PathToFileUri (path);
 			}
 		}
 
 		public string Description {
 			get {
-				if (img is JpegFile) 
-					return ((JpegFile)img).Description;
+				if (Image is JpegFile) 
+					return ((JpegFile)Image).Description;
 				else
 					return null;
 			}
@@ -88,7 +133,7 @@ namespace FSpot {
 
 		public string Name {
 			get {
-				return System.IO.Path.GetFileName (img.Path);
+				return System.IO.Path.GetFileName (Image.Path);
 			}
 		}
 	}
