@@ -1,7 +1,4 @@
 namespace FSpot {
 	public interface IPhotoCollection : IBrowsableCollection {
-	        Photo [] Photos {
-			get;
-		}
 	}
 }
